@@ -55,6 +55,8 @@ class RabbitMQConnector(IQueueConnector):
         exclusive: bool = False,
         auto_delete: bool = False,
         dead_letter_exchange: bool = False,
+        quorum: bool = False,
+        quorum_kwargs: Optional[Dict] = None,
         requeue_on_consumption_error=_DEFAULT,
     ):
         """
@@ -80,6 +82,8 @@ class RabbitMQConnector(IQueueConnector):
         :param exclusive:
         :param auto_delete: automatically delete queue when disconnected
         :param dead_letter_exchange: whether to set up DLX for failed messages
+        :param quorum: whether to set queue type to quorum
+        :param quorum_kwargs: kwargs related to quorum passed to queue declaraton
         :param requeue_on_consumption_error: whether to retry messages if processing failed
         """
         self._connection_parameters = connection_parameters
@@ -88,6 +92,8 @@ class RabbitMQConnector(IQueueConnector):
         self._exclusive = exclusive
         self._auto_delete = auto_delete
         self._dead_letter_exchange = f'dlx.{self._queue}' if dead_letter_exchange else None
+        self._quorum = quorum
+        self._quorum_kwargs = quorum_kwargs if quorum and quorum_kwargs else None
 
         self._requeue = (  # when using DLX, don't requeue failed messages by default
             requeue_on_consumption_error
@@ -105,9 +111,23 @@ class RabbitMQConnector(IQueueConnector):
         channel.confirm_delivery()
 
         queue_arguments = {}
+
         if self._dead_letter_exchange:
             queue_arguments['x-dead-letter-exchange'] = self._dead_letter_exchange
 
+        if self._quorum:
+            queue_arguments['x-queue-type'] = 'quorum'
+            queue_arguments['x-delivery-limit'] = int(
+                self._quorum_kwargs.get('x-delivery-limit', 3)
+            )
+            queue_arguments['x-max-in-memory-length'] = int(
+                self._quorum_kwargs.get('x-max-in-memory-length', 100)
+            )
+            # queue limit 1073741824b = 1gb
+            queue_arguments['x-max-in-memory-bytes'] = int(
+                self._quorum_kwargs.get('x-max-in-memory-bytes', 1073741824)
+            )
+
         queue_declaration = channel.queue_declare(
             queue=self._queue,
             durable=self._durable,
@@ -235,9 +255,11 @@ class RabbitMQConnector(IQueueConnector):
                 if self._requeue:
                     info['redelivered'] = deliver.redelivered
                 if self._dead_letter_exchange:
-                    x_death_header = (properties.headers or {}).get('x-death', [{}])[0]
+                    properties_header = properties.headers or {}
+                    x_death_header = properties_header.get('x-death', [{}])[0]
                     info['dlx_retry_count'] = x_death_header.get('count', 0)
                     info['dlx_last_fail_reason'] = x_death_header.get('reason')
+                    info['quorum-delivery-count'] = properties_header.get('x-delivery-count', 0)
 
                 try:
                     LOGGER.info("Processing message # %s, queue %s", tag, self._queue)
